aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/objective-c/GRPCClient/GRPCCall+ChannelArg.h
diff options
context:
space:
mode:
authorGravatar Kristopher Wuollett <klw@google.com>2016-02-02 22:38:40 -0500
committerGravatar Kristopher Wuollett <klw@google.com>2016-02-02 22:38:40 -0500
commit300f7e43225e21490dd7de3165d6fac3e29d2d5d (patch)
treef2f6bb047b2f1efd0734e0b946909e72478496a1 /src/objective-c/GRPCClient/GRPCCall+ChannelArg.h
parent2c6d2bd32787f9bdce1d46875dfee39e08881a3b (diff)
Renamed user agent setting to userAgentPrefix and changed its scope to global
Diffstat (limited to 'src/objective-c/GRPCClient/GRPCCall+ChannelArg.h')
-rw-r--r--src/objective-c/GRPCClient/GRPCCall+ChannelArg.h13
1 files changed, 4 insertions, 9 deletions
diff --git a/src/objective-c/GRPCClient/GRPCCall+ChannelArg.h b/src/objective-c/GRPCClient/GRPCCall+ChannelArg.h
index 11b2babbe7..045d31caf1 100644
--- a/src/objective-c/GRPCClient/GRPCCall+ChannelArg.h
+++ b/src/objective-c/GRPCClient/GRPCCall+ChannelArg.h
@@ -33,20 +33,15 @@
#import "GRPCCall.h"
/**
- * Methods to configure GRPC channel options for specific hosts.
+ * Methods to configure GRPC channel options.
*/
@interface GRPCCall (ChannelArg)
/**
* Use the provided @c primaryUserAgent at the beginning of the HTTP User Agent string for the
* provided @c host.
*/
-+ (void)usePrimaryUserAgent:(NSString *)primaryUserAgent forHost:(NSString *)host;
++ (void)setUserAgentPrefix:(NSString *)userAgentPrefix;
-/**
- * Use the provided @c secondaryUserAgent at the end of the HTTP User Agent string for the
- * provided @c host.
- */
-+ (void)useSecondaryUserAgent:(NSString *)secondaryUserAgent forHost:(NSString *)host;
++ (NSString *)useUserAgentPrefix;
@end
@@ -33,20 +33,15 @@
/**
- * Use the provided @c primaryUserAgent at the beginning of the HTTP User Agent string for the
- * provided @c host.
+ * Use the provided @c userAgentPrefix at the beginning of the HTTP User Agent string for all calls.
*/